<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Fondos de Anuncios de Películas</title>
    <style>
        /* Estilos generales */
        body {
            margin: 0;
            padding: 0;
            font-family: Arial, sans-serif;
            background-color: #000;
            color: #fff;
        }

        .container {
            display: flex;
            flex-direction: column;
            height: 100vh;
        }

        /* Estilos del banner */
        .banner {
            position: relative;
            flex: 1;
            background-size: cover;
            background-position: center;
            display: flex;
            align-items: flex-end;
            justify-content: flex-end; /* Alinea el contenido a la derecha */
            padding: 20px;
            box-shadow: inset 0 0 200px rgba(0, 0, 0, 0.9);
        }

        .banner-content {
            max-width: 40%; /* Ancho del contenido */
            text-align: right; /* Alinea el texto a la derecha */
            padding-right: 5%; /* Mueve el contenido un poco más al centro */
        }

        .banner-title {
            font-size: 1.8rem; /* Tamaño de fuente más pequeño */
            margin: 0;
            white-space: nowrap; /* Evita que el título se divida en varias líneas */
            overflow: hidden;
            text-overflow: ellipsis; /* Añade puntos suspensivos si el texto es muy largo */
        }

        .banner-info {
            font-size: 0.9rem; /* Tamaño de fuente más pequeño */
            margin: 10px 0 0;
            display: -webkit-box;
            -webkit-line-clamp: 3; /* Limita a 3 líneas */
            -webkit-box-orient: vertical;
            overflow: hidden;
            text-overflow: ellipsis; /* Añade puntos suspensivos si el texto es muy largo */
        }

        /* Estilos del carrusel */
        .carousel {
            height: 150px; /* Carrusel más pequeño */
            overflow: hidden;
            padding: 10px;
            position: relative;
        }

        .carousel-inner {
            display: flex;
            gap: 10px;
            position: absolute;
            white-space: nowrap;
            animation: scroll 30s linear infinite; /* Animación de autoscroll */
        }

        .carousel-inner img {
            height: 140px; /* Pósters más pequeños */
            border-radius: 10px;
            cursor: pointer;
            transition: transform 0.2s;
        }

        .carousel-inner img:hover {
            transform: scale(1.1);
        }

        /* Animación del carrusel */
        @keyframes scroll {
            0% {
                transform: translateX(0);
            }
            100% {
                transform: translateX(-50%);
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <!-- Sección de anuncios -->
        <div class="banner">
            <div class="banner-content">
                <h1 class="banner-title">Título de la Película</h1>
                <p class="banner-info">Información breve sobre la película.</p>
            </div>
        </div>

        <!-- Carrusel de pósters -->
        <div class="carousel">
            <div class="carousel-inner">
                <!-- Los pósters se insertarán dinámicamente aquí -->
            </div>
        </div>
    </div>

    <script>
        const API_KEY = '6b8e3eaa1a03ebb45642e9531d8a76d2'; // Tu clave API de TMDb
        const BASE_URL = 'https://api.themoviedb.org/3';
        const BANNER = document.querySelector('.banner');
        const CAROUSEL_INNER = document.querySelector('.carousel-inner');

        let currentMovieIndex = 0; // Índice de la película actual en el banner

        // Función para obtener películas populares
        async function fetchMovies() {
            try {
                const response = await fetch(`${BASE_URL}/movie/popular?api_key=${API_KEY}&language=es&page=1`);
                const data = await response.json();
                return data.results;
            } catch (error) {
                console.error('Error fetching movies:', error);
            }
        }

        // Función para actualizar el banner
        function updateBanner(movie) {
            BANNER.style.backgroundImage = `url(https://image.tmdb.org/t/p/original${movie.backdrop_path})`;
            BANNER.querySelector('.banner-title').textContent = movie.title;
            BANNER.querySelector('.banner-info').textContent = movie.overview.substring(0, 150) + '...';
        }

        // Función para cambiar el banner cada 8 segundos
        function startBannerRotation(movies) {
            setInterval(() => {
                currentMovieIndex = (currentMovieIndex + 1) % movies.length; // Cambia al siguiente índice
                updateBanner(movies[currentMovieIndex]);
            }, 8000); // Cambia cada 8 segundos
        }

        // Función para actualizar el carrusel
        function updateCarousel(movies) {
            CAROUSEL_INNER.innerHTML = '';
            movies.forEach(movie => {
                const poster = document.createElement('img');
                poster.src = `https://image.tmdb.org/t/p/w500${movie.poster_path}`;
                poster.alt = movie.title;
                CAROUSEL_INNER.appendChild(poster);
            });
        }

        // Inicializar la aplicación
        async function init() {
            const movies = await fetchMovies();
            if (movies && movies.length > 0) {
                updateBanner(movies[0]); // Mostrar la primera película en el banner
                startBannerRotation(movies); // Iniciar rotación del banner
                updateCarousel(movies); // Mostrar todas las películas en el carrusel
            }
        }

        init();
    </script>
</body>
</html>